@@ -73,7 +73,7 @@ class TheEyeofSauron:
 
         mongo_client.insert_data(self._customer, method.__name__, fetched_data)
 
-def ring_ruler(interface, interface_name, log_dir, key_path, test=False):
+def ring_ruler(interface, interface_name, log_dir, test=False):
     mongo_client = mongo.MongoDB()
 
     def fn(_customer, _interface, _interface_name):
@@ -89,12 +89,13 @@ def ring_ruler(interface, interface_name, log_dir, key_path, test=False):
     for customer in mongo_client.databases:
         fn(customer, interface, interface_name)
 
-    cache_server = caching.RedisCache()
-    cache_server.schedule_new_customers_checking(mongo_client, interface, interface_name, fn)
+    # Caching commented out since executor will already reset the process daily
+    # cache_server = caching.RedisCache()
+    # cache_server.schedule_new_customers_checking(mongo_client, interface, interface_name, fn)
 
     schedule.run_all() # run all jobs straight away so we're not left without data for long
 
-    # executor.schedule_log_sending_and_kill_process(log_dir, 'America/Sao_Paulo')
+    executor.schedule_log_sending_and_kill_process(log_dir, settings.TIMEZONE)
     if not(test):
         while True:
             schedule.run_pending()
